@@ -67,7 +67,12 @@ class NotFound(ZException):
     pass
 
 
-REQUIRED_METADATA_KEYS = {"*": ["TYPE_VERSION"], "1": ["TYPE", "VERSION"], "2": ["TYPE", "VERSION"]}
+REQUIRED_METADATA_KEYS = {
+    "*": ["TYPE_VERSION"],
+    "1": ["TYPE", "VERSION"],
+    "2": ["TYPE", "VERSION"],
+    "3": ["TYPE", "VERSION"],
+}
 
 
 @dataclass
@@ -79,6 +84,9 @@ class ProjectInfo:
 
 def get_project_info(path: str) -> ProjectInfo:
     project_name = os.path.basename(os.path.abspath(path))
+    if not os.path.exists(path):
+        raise NotFound(f"Path {path} does not exist.")
+
     metafile = os.path.join(path, ".dtproject")
     # if the file '.dtproject' is missing
     if not os.path.exists(metafile):
