@@ -18,11 +18,13 @@ from .credentials import DockerCredentials
 from .docker_logging_in import do_login_for_registry
 from .types import DockerCompleteImageName, DockerImageDigest
 
-__all__ = ["docker_push_optimized", "docker_push_retry", "DockerPushFailure"]
+__all__ = ["docker_push_optimized", "docker_push_retry", "DockerPushFailure", "docker_push_optimized_"]
 
 
 def docker_push_retry(
-    client: DockerClient, image_name: DockerCompleteImageName, credentials: DockerCredentials,
+    client: DockerClient,
+    image_name: DockerCompleteImageName,
+    credentials: DockerCredentials,
 ) -> DockerImageDigest:
     while True:
         # noinspection PyBroadException
@@ -42,12 +44,23 @@ class DockerPushFailure(ZException):
 
 
 def docker_push_optimized(
-    image_name: DockerCompleteImageName, credentials: DockerCredentials,
+    client: DockerClient,
+    image_name: DockerCompleteImageName,
+    credentials: DockerCredentials,
 ) -> DockerCompleteImageName:
-    """ Returns the *complete tag* for the image  "a/b:@sha256:...". Without tags. """
+    """Returns the *complete tag* for the image  "a/b:@sha256:...". Without tags."""
     f = parse_complete_tag(image_name)
 
-    client = DockerClient.from_env()
+    return docker_push_optimized_(client, image_name, credentials)
+
+
+def docker_push_optimized_(
+    client,
+    image_name: DockerCompleteImageName,
+    credentials: DockerCredentials,
+) -> DockerCompleteImageName:
+    """Returns the *complete tag* for the image  "a/b:@sha256:...". Without tags."""
+    f = parse_complete_tag(image_name)
 
     image = client.images.get(image_name)
     image_name_no_tag, _, _ = image_name.partition(":")
@@ -78,16 +91,6 @@ def push_image(
         msg = "Expecting either tag or digest"
         raise ZValueError(msg, image_name=image_name, br=br)
 
-    # if br.tag:
-    #     if not br.digest:
-    #         msg = 'I would have expected digest here'
-    #         logger.warning(msg, br=br)
-    #     else:
-    #         when, last_digest = docker_caching.get_last_tag_push(br.registry,
-    #                                                              br.organization,br.repository,
-    #                                                              br.tag)
-    #         if last_digest == br.digest:
-    #             logger.info('This has already been ')
     im = client.images.get(image_name)
     image_id = im.id
     if br.tag is not None:
@@ -122,7 +125,7 @@ def push_image(
     tag = parse_complete_tag(image_name)
     image_name_short = f"{tag.repository}"
 
-    do_login_for_registry(credentials, tag.registry)
+    do_login_for_registry(client, credentials, tag.registry)
 
     layer2size = {}
     layer2done = {}
@@ -142,7 +145,9 @@ def push_image(
         # logger.info(line=line)
         # percentage = max(0.0, min(1.0, len(pushed) / max(1.0, len(layers)))) * 100.0
         if "error" in line:
-            raise DockerPushFailure(str(line["error"]))
+            msg = "Cannot push image"
+            l = str(line["error"])
+            raise DockerPushFailure(msg, image_name=image_name, error=l)
 
         if "aux" in line:
             if "Digest" in line["aux"]:
