@@ -1,12 +1,10 @@
-import os
 from typing import cast, Dict, Iterator, List, Optional
 
 from zuper_commons.types import ZValueError
-
+from . import logger
 from .buildresult import parse_complete_tag
 from .misc import get_important_env_build_args_dict
 from .types import DockerCompleteImageName
-from . import logger
 
 __all__ = ["get_resolved_from"]
 
@@ -75,7 +73,7 @@ def replace_vars(s: str, variables: Dict[str, str]) -> str:
     return s
 
 
-def get_resolved_from(dockerfile_contents: str, arch="amd64") -> List[DockerCompleteImageName]:
+def get_resolved_from(dockerfile_contents: str) -> List[DockerCompleteImageName]:
     varvalues = get_important_env_build_args_dict(dockerfile_contents)
 
     res = []
@@ -97,7 +95,7 @@ def get_resolved_from(dockerfile_contents: str, arch="amd64") -> List[DockerComp
             #     dockerfile_contents=dockerfile_contents)
         variables[k] = v2
 
-    variables["ARCH"] = arch  # XXX
+    # variables["ARCH"] = arch  # XXX
     # logger.debug(varvalues=varvalues, variables0=variables0, variables=variables)
     froms = get_FROM(dockerfile_contents)
     # logger.debug(froms=froms)
